@@ -12,7 +12,7 @@ use English qw/ -no_match_vars /;
 use App::Git::Workflow::Pom;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION  = 0.97;
+our $VERSION  = 0.98;
 our $workflow = App::Git::Workflow::Pom->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -91,8 +91,9 @@ sub jira {
     my $jira_rest = JIRA::REST->new($option{url}, $option{user}, $option{pass});
     my $issue     = $jira_rest->GET("/issue/$option{jira}");
     my $branch    = lc "$option{jira} $issue->{fields}{summary}";
+
     # remove unsafe characters
-    $branch =~ s/[ .:!?|\/\\-]+/_/gxms;
+    $branch =~ s/[&'" .:!?|\/\\-]+/_/gxms;
     # remove leading and trailing underscores
     $branch =~ s/^_+|_+$//gxms;
     # remove doubled underscores
@@ -111,7 +112,7 @@ git-feature - Create a feature branch from the "current release"
 
 =head1 VERSION
 
-This documentation refers to git-feature version 0.97
+This documentation refers to git-feature version 0.98
 
 =head1 SYNOPSIS
 
